/*
 * TopView.cpp
 * 
 * Copyright (C) 2008 Matthias Schiffer <matthias@gamezock.de>
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "TopView.h"
#include <Data/Level.h>
#include <Data/Room.h>
#include <Data/Triangle.h>
#include <GL/gl.h>

namespace ZoomEdit {
namespace View {

void TopView::renderRoom(Data::Room *room) {
  const std::list<Data::Triangle*> &floor = room->getFloorTriangles();
  
  glColor4f(0.0f, 0.7f, 1.0f, 0.3f);
  
  glBegin(GL_TRIANGLES);
  
  for(std::list<Data::Triangle*>::const_iterator t = floor.begin(); t != floor.end(); ++t) {
    for(int i = 0; i < 3; ++i) {
      const Data::Vertex &v = (*t)->getVertex(i);
      glVertex2f(v.getX(), v.getZ());
    }
  }
  
  glEnd();
}

void TopView::render() {
  if(!level)
    return;
  
  const std::list<Data::Room*> &rooms = level->getRooms();
  
  for(std::list<Data::Room*>::const_iterator room = rooms.begin(); room != rooms.end(); ++room)
    renderRoom(*room);
}

}
}
